// Copyright (c) 2023 mStar
// 
// Licensed under the EUPL, Version 1.2
// 
// You may not use this work except in compliance with the Licence.
// You should have received a copy of the Licence along with this work. If not, see:
// <https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12>.
// See the Licence for the specific language governing permissions and limitations under the Licence.
// 

use diesel::{prelude::*, sqlite::Sqlite};
use diesel::pg::PgConnection;
use diesel_migrations::{EmbeddedMigrations, embed_migrations, MigrationHarness};
use dotenvy::dotenv;
use std::{env, error::Error};


pub const MIGRATIONS: EmbeddedMigrations = embed_migrations!("migrations");

pub fn establish_connection(db_url: &str) -> PgConnection {
    dotenv().ok();
    let conn = PgConnection::establish(db_url)
        .unwrap_or_else(|_| panic!("Error connecting to {}", db_url));
    // TODO: Add migrations here
    conn
}


fn run_migrations_sqlite(connection: &mut impl MigrationHarness<Sqlite>) -> Result<(), Box<dyn Error + Send + Sync + 'static>> {

    // This will run the necessary migrations.
    //
    // See the documentation for `MigrationHarness` for
    // all available methods.
    connection.run_pending_migrations(MIGRATIONS)?;

    Ok(())
}